"""Various utility functions to avoid boilerplate when performing common operations."""
import pathlib
import sys
from contextlib import contextmanager
from typing import Generator, Union


@contextmanager
def syspath_prepend(path: Union[pathlib.Path, str]) -> Generator:
    """Temporarily prepend `path` to `sys.path` for the duration of the `with` block."""
    # NOTE. It is not thread-safe to use as is now.
    # In the future it might require an `RLock` to avoid concurrent access to `sys.path`.
    current = sys.path[:]
    # Use `insert` to put the value to the 0th position in `sys.path`. The given path will be the first one to check.
    sys.path.insert(0, str(path))
    try:
        yield
    finally:
        sys.path[:] = current



from typing import Optional, Tuple

import attr

CONFIG_VERSION = (1, 0)


@attr.s(slots=True)
class PlanConfig:
    """Test plan configuration."""

    spec_path: str = attr.ib(kw_only=True)
    target_url: str = attr.ib(kw_only=True)
    auth: Optional[Tuple[str, str]] = attr.ib(kw_only=True)
    auth_type: str = attr.ib(kw_only=True)
    report_to_saas: bool = attr.ib(kw_only=True)
    # Current config version
    version = CONFIG_VERSION
